.. image:: https://img.shields.io/pypi/v/penaltymodel.svg
    :target: https://pypi.python.org/pypi/penaltymodel

D-Wave Penalty Model - Core
===========================

.. index-start-marker

The core penalty model package. Contains the logic shared in the penalty model ecosystem.

.. index-end-marker

Installation
------------

.. installation-start-marker

To install:

.. code-block:: bash

    pip install penaltymodel

To build from souce:

.. code-block:: bash
    
    cd penatlymodel_core
    pip install -r requirements.txt
    python setup.py install

.. installation-end-marker


License
-------

Released under the Apache License 2.0